import telebot
from telebot.types import InlineKeyboardMarkup, InlineKeyboardButton
import json
import logging
import os
import time

logging.basicConfig(
    level=logging.INFO,
    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s'
)
logger = logging.getLogger(__name__)


API_TOKEN = '8088429033:AAFZdfvmUvkc1t7bma2kzCIQxJ0SK1c31nc'
CHECKS_FILE = os.path.abspath('checks.json')
USDT_TO_RUB_RATE = 81.61

bot = telebot.TeleBot(API_TOKEN)
checks = {}

def load_checks():
    global checks
    try:
        with open(CHECKS_FILE, 'r') as f:
            checks = json.load(f)
            logger.info(f"Successfully loaded checks from {CHECKS_FILE}: {list(checks.keys())}")
    except FileNotFoundError:
        logger.error(f"{CHECKS_FILE} not found. Starting with empty checks.")
        checks = {}
    except json.JSONDecodeError as e:
        logger.error(f"Failed to parse {CHECKS_FILE}: {e}. Starting with empty checks.")
        checks = {}
    except Exception as e:
        logger.error(f"Unexpected error loading {CHECKS_FILE}: {e}")
        checks = {}

load_checks()

@bot.message_handler(commands=['start'])
def handle_start(message):
    chat_id = message.chat.id
    user_id = message.from_user.id
    args = message.text.split()
    
    check_id = args[1] if len(args) > 1 else None
    logger.info(f"Received /start with check_id: {check_id} from user {user_id}")
    
    load_checks()  # Ensure latest checks data
    
    # Handle gift links
    if check_id and check_id.startswith("gift"):
        gift_id = check_id[4:]  # Extract gift ID
        if gift_id not in checks or checks[gift_id].get('type') != 'gift':
            logger.warning(f"Invalid or missing gift_id: {gift_id}. Available checks: {list(checks.keys())}")
            try:
                bot.send_message(
                    chat_id,
                    "<b>❌ Неверный или недействительный подарок!</b>\n\n"
                    "<i>Проверьте ссылку или свяжитесь с поддержкой @CrypppppppptoBOT.</i>",
                    parse_mode="HTML"
                )
            except Exception as e:
                logger.error(f"Failed to send error message to {chat_id}: {e}")
            return
        
        check_data = checks[gift_id]
        amount = check_data.get('amount', 0.0)
        telegraph_url = check_data.get('telegraph_url', '')
        
        markup = InlineKeyboardMarkup()
        markup.add(InlineKeyboardButton("🎁 Получить подарок", url=telegraph_url))
        
        text = f"""
🎁 У меня для тебя <b>подарок!</b> Нажми на кнопку ниже, чтобы получить его.
"""
        try:
            bot.send_photo(
                chat_id,
                "https://files.catbox.moe/nuq5gr.jpg",
                caption=text,
                parse_mode="HTML",
                reply_markup=markup
            )
            logger.info(f"Sent gift details for gift_id {gift_id} to user {user_id}")
        except Exception as e:
            logger.error(f"Failed to send gift details to {chat_id}: {e}")
        return
    
    # Handle check links
    if not check_id or check_id not in checks:
        logger.warning(f"Invalid or missing check_id: {check_id}. Available checks: {list(checks.keys())}")
        try:
            bot.send_message(
                chat_id,
                "<b>❌ Неверный или недействительный чек!</b>\n\n"
                "<i>Проверьте ссылку или свяжитесь с поддержкой @CrypppppppptoBOT.</i>",
                parse_mode="HTML"
            )
        except Exception as e:
            logger.error(f"Failed to send error message to {chat_id}: {e}")
        return
    
    check_data = checks[check_id]
    amount = check_data.get('amount', 0.0)
    telegraph_url = check_data.get('telegraph_url', '')
    rub_amount = amount * USDT_TO_RUB_RATE
    check_image_url = f"https://imggen.send.tg/checks/image?asset=USDT&asset_amount={amount}&fiat=RUB&fiat_amount={rub_amount}&main=asset&v2"
    
    markup = InlineKeyboardMarkup()
    markup.add(InlineKeyboardButton(f"Получить {amount:.1f} USDT", url=telegraph_url))
    
    text = f"""
🦋 <a href="https://t.me/CryptoBotRU/23">Чек</a> на <b>{amount:.1f} USDT ({rub_amount:.2f} RUB)</b>
"""
    try:
        bot.send_photo(chat_id, check_image_url, caption=text, parse_mode="HTML", reply_markup=markup)
        logger.info(f"Sent check details for check_id {check_id} to user {user_id}")
    except Exception as e:
        logger.error(f"Failed to send check details to {chat_id}: {e}")

def main():
    logger.info("🚀 CryptoBot started!")
    while True:
        try:
            bot.infinity_polling(timeout=60, long_polling_timeout=30)
        except Exception as e:
            logger.error(f"Polling error: {e}")
            logger.info("Restarting polling in 10 seconds...")
            time.sleep(10)

if __name__ == "__main__":
    main()