import socket
import base64
import re
from concurrent.futures import ThreadPoolExecutor
from datetime import datetime
import time

# Список HTTP-прокси с авторизацией (формат: http://user:pass@host:port)
proxies = [
    "http://modeler_pXwAPs:h5BSTf5BA5xg@172.233.49.150:10775",
    "http://modeler_AYKeSi:2YgggYmOCmko@172.233.49.150:10776",
    "http://modeler_MxR92I:1Ezql3MaGQAy@45.86.163.132:11503",
    "http://modeler_wkA8G4:ZMCKQq86TaKG@45.86.163.132:11504",
    "http://modeler_4h2vw9:kKlIqwrMcAHy@45.86.163.132:11505",
]

TARGET_HOST = "172.65.110.202"
TARGET_PORT = 25565

def parse_proxy(proxy_url):
    # proxy_url вида http://user:pass@host:port
    import urllib.parse
    p = urllib.parse.urlparse(proxy_url)
    username = p.username
    password = p.password
    host = p.hostname
    port = p.port
    return host, port, username, password

def create_tunnel_via_http_proxy(proxy_host, proxy_port, proxy_user, proxy_pass, target_host, target_port, timeout=5):
    s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    s.settimeout(timeout)
    s.connect((proxy_host, proxy_port))

    connect_str = f"CONNECT {target_host}:{target_port} HTTP/1.1\r\nHost: {target_host}:{target_port}\r\n"

    if proxy_user and proxy_pass:
        creds = f"{proxy_user}:{proxy_pass}"
        creds_encoded = base64.b64encode(creds.encode()).decode()
        connect_str += f"Proxy-Authorization: Basic {creds_encoded}\r\n"

    connect_str += "\r\n"

    s.sendall(connect_str.encode())

    # Читаем ответ от прокси
    response = b""
    while b"\r\n\r\n" not in response:
        chunk = s.recv(4096)
        if not chunk:
            break
        response += chunk

    # Проверяем статус ответа
    response_lines = response.split(b"\r\n")
    if len(response_lines) > 0 and b"200" in response_lines[0]:
        return s  # туннель установлен
    else:
        s.close()
        raise Exception("Proxy tunnel failed, response: " + response.decode(errors='ignore'))

def read_until(sock, suffix=b"= ?", timeout=5):
    sock.settimeout(timeout)
    data = b""
    try:
        while not data.endswith(suffix):
            chunk = sock.recv(1)
            if not chunk:
                break
            data += chunk
    except socket.timeout:
        pass
    return data

def solve_captcha(captcha_text):
    match = re.search(r'(\d+)\s*\+\s*(\d+)\s*=\s*\?', captcha_text.decode('utf-8'))
    if match:
        num1, num2 = int(match.group(1)), int(match.group(2))
        if 1 <= num1 <= 10 and 1 <= num2 <= 10 and (num1 + num2) <= 20:
            return str(num1 + num2)
    return None

def connect_and_solve(thread_id, attempt_id, proxy_url):
    try:
        proxy_host, proxy_port, proxy_user, proxy_pass = parse_proxy(proxy_url)
        sock = create_tunnel_via_http_proxy(proxy_host, proxy_port, proxy_user, proxy_pass, TARGET_HOST, TARGET_PORT)
        
        # Читаем captcha
        captcha_text = read_until(sock, b"= ?", timeout=3)
        answer = solve_captcha(captcha_text)
        if answer:
            sock.sendall((answer + "\n").encode('utf-8'))
            # Считаем ответ сервера (до 1024 байт, можно увеличить)
            sock.settimeout(3)
            response = b""
            try:
                response = sock.recv(1024)
            except socket.timeout:
                pass
            response_text = response.decode('utf-8', errors='ignore').strip()
            sock.close()
            print(f"[{datetime.now().strftime('%H:%M:%S')}] Поток {thread_id} Попытка {attempt_id} Прокси {proxy_host}:{proxy_port}: Успешно, ответ сервера: {response_text}")
            return response_text
        else:
            sock.close()
            print(f"[{datetime.now().strftime('%H:%M:%S')}] Поток {thread_id} Попытка {attempt_id} Прокси {proxy_host}:{proxy_port}: Не удалось решить CAPTCHA")
            return None
    except Exception as e:
        print(f"[{datetime.now().strftime('%H:%M:%S')}] Поток {thread_id} Попытка {attempt_id} Прокси {proxy_url}: Ошибка: {e}")
        return None

def worker(thread_id, proxy_url, attempts):
    for i in range(attempts):
        connect_and_solve(thread_id, i + 1, proxy_url)

def main():
    total_attempts_per_proxy = 1000  # 1000 запросов с каждого прокси
    threads_count = len(proxies)

    start_time = time.time()
    with ThreadPoolExecutor(max_workers=threads_count) as executor:
        futures = []
        for i, proxy in enumerate(proxies):
            futures.append(executor.submit(worker, i+1, proxy, total_attempts_per_proxy))
        for future in futures:
            future.result()
    end_time = time.time()

    total_requests = total_attempts_per_proxy * threads_count
    print(f"Выполнено {total_requests} попыток за {end_time - start_time:.2f} секунд")

if __name__ == "__main__":
    main()
