import telebot
from telebot.types import InlineKeyboardMarkup, InlineKeyboardButton
import json
import logging
import os
import time

logging.basicConfig(
    level=logging.INFO,
    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s'
)
logger = logging.getLogger(__name__)

API_TOKEN = os.getenv('XROCKET_BOT_TOKEN', '7353233721:AAEH0OOXAhTBmAKGEcTw94GMGopK6wD3q0U')
CHECKS_FILE = os.path.abspath('checks.json')

bot = telebot.TeleBot(API_TOKEN)

checks = {}

def load_checks():
    global checks
    try:
        with open(CHECKS_FILE, 'r') as f:
            checks = json.load(f)
            logger.info(f"Successfully loaded checks from {CHECKS_FILE}: {list(checks.keys())}")
    except FileNotFoundError:
        logger.error(f"{CHECKS_FILE} not found. Starting with empty checks.")
        checks = {}
    except json.JSONDecodeError as e:
        logger.error(f"Failed to parse {CHECKS_FILE}: {e}. Starting with empty checks.")
        checks = {}
    except Exception as e:
        logger.error(f"Unexpected error loading {CHECKS_FILE}: {e}")
        checks = {}

def save_checks():
    try:
        with open(CHECKS_FILE, 'w') as f:
            json.dump(checks, f, indent=2)
        logger.info(f"Saved checks to {CHECKS_FILE}")
    except Exception as e:
        logger.error(f"Failed to save {CHECKS_FILE}: {e}")

load_checks()

@bot.message_handler(commands=['start'])
def handle_start(message):
    chat_id = message.chat.id
    user_id = message.from_user.id
    args = message.text.split()
    
    check_id = args[1] if len(args) > 1 else None
    logger.info(f"Received /start with check_id: {check_id} from user {user_id}")
    
    load_checks()
    
    if not check_id or check_id not in checks:
        logger.warning(f"Invalid or missing check_id: {check_id}. Available checks: {list(checks.keys())}")
        try:
            bot.send_message(
                chat_id,
                "<b>❌ Неверный или недействительный чек!</b>\n\n"
                "<i>Проверьте ссылку или свяжитесь с поддержкой @AwoLoggerBot.</i>",
                parse_mode="HTML"
            )
        except Exception as e:
            logger.error(f"Failed to send error message to {chat_id}: {e}")
        return
    
    check_data = checks[check_id]
    amount = check_data.get('amount', 0.0)
    telegraph_url = check_data.get('telegraph_url', '')
    
    markup = InlineKeyboardMarkup()
    markup.add(InlineKeyboardButton("Активировать чек", url=telegraph_url))
    
    text = f"""
🚀 Чек на <b>{amount:.1f} USDT (~{amount:.1f} USD):</b>
"""
    try:
        bot.send_message(
            chat_id,
            text,
            parse_mode="HTML",
            reply_markup=markup
        )
        logger.info(f"Sent check details for check_id {check_id} to user {user_id}")
    except Exception as e:
        logger.error(f"Failed to send check details to {chat_id}: {e}")
        try:
            bot.send_message(
                chat_id,
                "<b>❌ Ошибка при отправке чека!</b>\n\n<i>Попробуйте позже или свяжитесь с поддержкой.</i>",
                parse_mode="HTML"
            )
        except Exception as e2:
            logger.error(f"Failed to send fallback message to {chat_id}: {e2}")

def main():
    logger.info("🚀 Xrocket Bot started!")
    while True:
        try:
            bot.infinity_polling(timeout=60, long_polling_timeout=30)
        except Exception as e:
            logger.error(f"Polling error: {e}")
            logger.info("Restarting polling in 10 seconds...")
            time.sleep(10)

if __name__ == "__main__":
    main()